==> blackdogosint-0.1.40.tar.gz: blackdogosint-0.1.40/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['blackdogosint',
 'blackdogosint.mods',
 'blackdogosint.mods.Archives',
 'blackdogosint.mods.Business_Records',
 'blackdogosint.mods.Classifieds',
 'blackdogosint.mods.Dark_Web',
 'blackdogosint.mods.Dating',
 'blackdogosint.mods.Digital_Currency',
 'blackdogosint.mods.Documentation',
 'blackdogosint.mods.Domain_Name',
 'blackdogosint.mods.Email_Address',
 'blackdogosint.mods.Encoding_Decoding',
 'blackdogosint.mods.Exploits_e_Advisories',
 'blackdogosint.mods.Forum_Blog_IRC',
 'blackdogosint.mods.Geolocation_Tool_Maps',
 'blackdogosint.mods.IP_Address',
 'blackdogosint.mods.IP_Address.Geolocation',
 'blackdogosint.mods.IP_Address.Geolocation.My_IP_Address',
 'blackdogosint.mods.Image_Video_Docs',
 'blackdogosint.mods.Instant_Messaging',
 'blackdogosint.mods.Language_Translation',
 'blackdogosint.mods.Malicious_File_Analysis',
 'blackdogosint.mods.Metadata',
 'blackdogosint.mods.Mobile_Emulation',
 'blackdogosint.mods.OpSec',
 'blackdogosint.mods.People_Search_Engines',
 'blackdogosint.mods.Public_Records',
 'blackdogosint.mods.ScreenShot',
 'blackdogosint.mods.Search',
 'blackdogosint.mods.Search.google',
 'blackdogosint.mods.Search_Engines',
 'blackdogosint.mods.Social_Networks',
 'blackdogosint.mods.Telephone_Numbers',
 'blackdogosint.mods.Terrorism',
 'blackdogosint.mods.Threat_Intelligence',
 'blackdogosint.mods.Tools',
 'blackdogosint.mods.Trainings',
 'blackdogosint.mods.Transportation',
 'blackdogosint.mods.Username',
 'blackdogosint.mods.Username.Specific_Sites',
 'blackdogosint.mods.Username.Username_Search_Engines',
 'blackdogosint.osintlib',
 'blackdogosint.osintlib.Archives',
 'blackdogosint.osintlib.Business_Records',
 'blackdogosint.osintlib.Classifieds',
 'blackdogosint.osintlib.Dark_Web',
 'blackdogosint.osintlib.Dating',
 'blackdogosint.osintlib.Digital_Currency',
 'blackdogosint.osintlib.Documentation',
 'blackdogosint.osintlib.Domain_Name',
 'blackdogosint.osintlib.Email_Address',
 'blackdogosint.osintlib.Encoding_Decoding',
 'blackdogosint.osintlib.Exploits_e_Advisories',
 'blackdogosint.osintlib.Forum_Blog_IRC',
 'blackdogosint.osintlib.Geolocation_Tool_Maps',
 'blackdogosint.osintlib.IP_Address',
 'blackdogosint.osintlib.IP_Address.Geolocation',
 'blackdogosint.osintlib.IP_Address.Geolocation.My_IP_Address',
 'blackdogosint.osintlib.Image_Video_Docs',
 'blackdogosint.osintlib.Instant_Messaging',
 'blackdogosint.osintlib.Language_Translation',
 'blackdogosint.osintlib.Malicious_File_Analysis',
 'blackdogosint.osintlib.Metadata',
 'blackdogosint.osintlib.Mobile_Emulation',
 'blackdogosint.osintlib.OpSec',
 'blackdogosint.osintlib.People_Search_Engines',
 'blackdogosint.osintlib.Public_Records',
 'blackdogosint.osintlib.ScreenShot',
 'blackdogosint.osintlib.Search',
 'blackdogosint.osintlib.Search.google',
 'blackdogosint.osintlib.Search_Engines',
 'blackdogosint.osintlib.Social_Networks',
 'blackdogosint.osintlib.Telephone_Numbers',
 'blackdogosint.osintlib.Terrorism',
 'blackdogosint.osintlib.Threat_Intelligence',
 'blackdogosint.osintlib.Tools',
 'blackdogosint.osintlib.Trainings',
 'blackdogosint.osintlib.Transportation',
 'blackdogosint.osintlib.Username',
 'blackdogosint.osintlib.Username.Specific_Sites',
 'blackdogosint.osintlib.Username.Username_Search_Engines',
 'blackdogosint.utils',
 'blackdogosint.utils.data',
 'blackdogosint.utils.parsers',
 'blackdogosint.utils.term',
 'blackdogosint.utils.utils',
 'blackdogosint.utils.utils.discovery',
 'blackdogosint.utils.utils.lib']

package_data = \
{'': ['*']}

install_requires = \
['Django>=3.2.4,<4.0.0',
 'Pillow>=8.2.0,<9.0.0',
 'PySocks>=1.7.1,<2.0.0',
 'aiodns==3.0.0',
 'aiosqlite>=0.17.0,<0.18.0',
 'colored-traceback>=0.3.0,<0.4.0',
 'fastapi==0.66.0',
 'flake8==3.9.2',
 'google>=3.0.0,<4.0.0',
 'import-linter>=1.2.1,<2.0.0',
 'importanize>=0.7.0,<0.8.0',
 'isort[pipfile_deprecated_finder,requirements_deprecated_finder]>=5.9.1,<6.0.0',
 'mkdocs-bootswatch>=1.1,<2.0',
 'mkdocs-material>=7.1.9,<8.0.0',
 'mkdocs>=1.2.1,<2.0.0',
 'mypy-extensions==0.4.3',
 'mypy==0.910',
 'osint>=0.5,<0.6',
 'pyflakes==2.3.1',
 'pyright>=0.0.2,<0.0.3',
 'pytest-asyncio==0.15.1',
 'pytype>=2021.6.17,<2022.0.0',
 'requests>=2.25.1,<3.0.0',
 'search-engine-parser>=0.6.2,<0.7.0',
 'selenium>=3.141.0,<4.0.0',
 'six>=1.16.0,<2.0.0',
 'slowapi>=0.1.4,<0.2.0',
 'socks>=0,<1',
 'standalone>=1.0.1,<2.0.0',
 'toml>=0.10.2,<0.11.0',
 'types-PyYAML==5.4.3',
 'types-certifi==0.1.4',
 'types-chardet==0.1.3',
 'types-freezegun>=0.1.4,<0.2.0',
 'types-orjson==0.1.1',
 'types-pathlib2>=0.1.6,<0.2.0',
 'types-pynamodb>=0.1,<0.2',
 'types-pytz>=2021.1.0,<2022.0.0',
 'types-requests==0.1.11',
 'types-six>=0.1.7,<0.2.0',
 'types-tabulate>=0.1.1,<0.2.0']

setup_kwargs = {
    'name': 'blackdogosint',
    'version': '0.1.40',
    'description': 'api supporting OSINT open source queries',
    'long_description': None,
    'author': 'darkcode357',
    'author_email': 'darkcode357@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<3.10',
}


setup(**setup_kwargs)

==> blackdogosint-0.1.41.tar.gz: blackdogosint-0.1.41/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['blackdogosint',
 'blackdogosint.mods',
 'blackdogosint.mods.Archives',
 'blackdogosint.mods.Business_Records',
 'blackdogosint.mods.Classifieds',
 'blackdogosint.mods.Dark_Web',
 'blackdogosint.mods.Dating',
 'blackdogosint.mods.Digital_Currency',
 'blackdogosint.mods.Documentation',
 'blackdogosint.mods.Domain_Name',
 'blackdogosint.mods.Email_Address',
 'blackdogosint.mods.Encoding_Decoding',
 'blackdogosint.mods.Exploits_e_Advisories',
 'blackdogosint.mods.Forum_Blog_IRC',
 'blackdogosint.mods.Geolocation_Tool_Maps',
 'blackdogosint.mods.IP_Address',
 'blackdogosint.mods.IP_Address.Geolocation',
 'blackdogosint.mods.IP_Address.HostPortDiscovery',
 'blackdogosint.mods.Image_Video_Docs',
 'blackdogosint.mods.Instant_Messaging',
 'blackdogosint.mods.Language_Translation',
 'blackdogosint.mods.Malicious_File_Analysis',
 'blackdogosint.mods.Metadata',
 'blackdogosint.mods.Mobile_Emulation',
 'blackdogosint.mods.OpSec',
 'blackdogosint.mods.People_Search_Engines',
 'blackdogosint.mods.Public_Records',
 'blackdogosint.mods.ScreenShot',
 'blackdogosint.mods.Search',
 'blackdogosint.mods.Search.discovery',
 'blackdogosint.mods.Search.google',
 'blackdogosint.mods.Search_Engines',
 'blackdogosint.mods.Social_Networks',
 'blackdogosint.mods.Telephone_Numbers',
 'blackdogosint.mods.Terrorism',
 'blackdogosint.mods.Threat_Intelligence',
 'blackdogosint.mods.Tools',
 'blackdogosint.mods.Trainings',
 'blackdogosint.mods.Transportation',
 'blackdogosint.mods.Username',
 'blackdogosint.mods.Username.Specific_Sites',
 'blackdogosint.mods.Username.Username_Search_Engines',
 'blackdogosint.osintlib',
 'blackdogosint.osintlib.Archives',
 'blackdogosint.osintlib.Business_Records',
 'blackdogosint.osintlib.Classifieds',
 'blackdogosint.osintlib.Dark_Web',
 'blackdogosint.osintlib.Dating',
 'blackdogosint.osintlib.Digital_Currency',
 'blackdogosint.osintlib.Documentation',
 'blackdogosint.osintlib.Domain_Name',
 'blackdogosint.osintlib.Email_Address',
 'blackdogosint.osintlib.Encoding_Decoding',
 'blackdogosint.osintlib.Exploits_e_Advisories',
 'blackdogosint.osintlib.Forum_Blog_IRC',
 'blackdogosint.osintlib.Geolocation_Tool_Maps',
 'blackdogosint.osintlib.IP_Address',
 'blackdogosint.osintlib.IP_Address.Geolocation',
 'blackdogosint.osintlib.IP_Address.Geolocation.My_IP_Address',
 'blackdogosint.osintlib.Image_Video_Docs',
 'blackdogosint.osintlib.Instant_Messaging',
 'blackdogosint.osintlib.Language_Translation',
 'blackdogosint.osintlib.Malicious_File_Analysis',
 'blackdogosint.osintlib.Metadata',
 'blackdogosint.osintlib.Mobile_Emulation',
 'blackdogosint.osintlib.OpSec',
 'blackdogosint.osintlib.People_Search_Engines',
 'blackdogosint.osintlib.Public_Records',
 'blackdogosint.osintlib.ScreenShot',
 'blackdogosint.osintlib.Search',
 'blackdogosint.osintlib.Search.google',
 'blackdogosint.osintlib.Search_Engines',
 'blackdogosint.osintlib.Social_Networks',
 'blackdogosint.osintlib.Telephone_Numbers',
 'blackdogosint.osintlib.Terrorism',
 'blackdogosint.osintlib.Threat_Intelligence',
 'blackdogosint.osintlib.Tools',
 'blackdogosint.osintlib.Trainings',
 'blackdogosint.osintlib.Transportation',
 'blackdogosint.osintlib.Username',
 'blackdogosint.osintlib.Username.Specific_Sites',
 'blackdogosint.osintlib.Username.Username_Search_Engines',
 'blackdogosint.utils',
 'blackdogosint.utils.blackdogrequest',
 'blackdogosint.utils.blackdogrequest.utils',
 'blackdogosint.utils.data',
 'blackdogosint.utils.database',
 'blackdogosint.utils.database.tabelas',
 'blackdogosint.utils.exception',
 'blackdogosint.utils.parsers',
 'blackdogosint.utils.parsers.generic',
 'blackdogosint.utils.proxy']

package_data = \
{'': ['*']}

install_requires = \
['Django>=3.2.4,<4.0.0',
 'Flask-SQLAlchemy>=2.5.1,<3.0.0',
 'Pillow>=8.2.0,<9.0.0',
 'Proxy-List-Scrapper>=0.2.2,<0.3.0',
 'PySocks>=1.7.1,<2.0.0',
 'SQLAlchemy>=1.4.21,<2.0.0',
 'aiodns==3.0.0',
 'aiosqlite>=0.17.0,<0.18.0',
 'certifi>=2021.5.30,<2022.0.0',
 'colored-traceback>=0.3.0,<0.4.0',
 'docker>=5.0.0,<6.0.0',
 'fastapi==0.66.0',
 'flake8==3.9.2',
 'google>=3.0.0,<4.0.0',
 'import-linter>=1.2.1,<2.0.0',
 'importanize>=0.7.0,<0.8.0',
 'isort[requirements_deprecated_finder,pipfile_deprecated_finder]>=5.9.1,<6.0.0',
 'mkdocs-bootswatch>=1.1,<2.0',
 'mkdocs-material>=7.1.9,<8.0.0',
 'mkdocs>=1.2.1,<2.0.0',
 'mypy-extensions==0.4.3',
 'mypy==0.910',
 'osint>=0.5,<0.6',
 'pwn>=1.0,<2.0',
 'pyflakes==2.3.1',
 'pyright>=0.0.2,<0.0.3',
 'pytest-asyncio==0.15.1',
 'pytype>=2021.6.17,<2022.0.0',
 'requests>=2.25.1,<3.0.0',
 'search-engine-parser>=0.6.2,<0.7.0',
 'selenium>=3.141.0,<4.0.0',
 'shodan>=1.25.0,<2.0.0',
 'six>=1.16.0,<2.0.0',
 'slowapi>=0.1.4,<0.2.0',
 'socks>=0,<1',
 'standalone>=1.0.1,<2.0.0',
 'tabulate>=0.8.9,<0.9.0',
 'toml>=0.10.2,<0.11.0',
 'types-PyYAML==5.4.3',
 'types-certifi==0.1.4',
 'types-chardet==0.1.3',
 'types-freezegun>=0.1.4,<0.2.0',
 'types-orjson==0.1.1',
 'types-pathlib2>=0.1.6,<0.2.0',
 'types-pynamodb>=0.1,<0.2',
 'types-pytz>=2021.1.0,<2022.0.0',
 'types-requests==0.1.11',
 'types-six>=0.1.7,<0.2.0',
 'types-tabulate>=0.1.1,<0.2.0']

setup_kwargs = {
    'name': 'blackdogosint',
    'version': '0.1.41',
    'description': 'api supporting OSINT open source queries',
    'long_description': None,
    'author': 'darkcode357',
    'author_email': 'darkcode357@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.1,<4.0',
}


setup(**setup_kwargs)
